Class: Aws::FreeTier::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::FreeTier::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-freetier/client.rb,
sig/client.rbs
Overview
An API client for FreeTier. To construct a client, you need to configure a :region and :credentials.
client = Aws::FreeTier::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _GetAccountActivityResponseSuccess, _GetAccountPlanStateResponseSuccess, _GetFreeTierUsageResponseSuccess, _ListAccountActivitiesResponseSuccess, _UpgradeAccountPlanResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_account_activity(params = {}) ⇒ Types::GetAccountActivityResponse
Returns a specific activity record that is available to the customer.
-
#get_account_plan_state(params = {}) ⇒ Types::GetAccountPlanStateResponse
This returns all of the information related to the state of the account plan related to Free Tier.
-
#get_free_tier_usage(params = {}) ⇒ Types::GetFreeTierUsageResponse
Returns a list of all Free Tier usage objects that match your filters.
-
#list_account_activities(params = {}) ⇒ Types::ListAccountActivitiesResponse
Returns a list of activities that are available.
-
#upgrade_account_plan(params = {}) ⇒ Types::UpgradeAccountPlanResponse
The account plan type for the Amazon Web Services account.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-freetier/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
895 896 897 |
# File 'lib/aws-sdk-freetier/client.rb', line 895 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
898 899 900 |
# File 'lib/aws-sdk-freetier/client.rb', line 898 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 |
# File 'lib/aws-sdk-freetier/client.rb', line 868 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::FreeTier') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-freetier' context[:gem_version] = '1.39.0' Seahorse::Client::Request.new(handlers, context) end |
#get_account_activity(params = {}) ⇒ Types::GetAccountActivityResponse
Returns a specific activity record that is available to the customer.
96 |
# File 'sig/client.rbs', line 96
def get_account_activity: (
|
#get_account_plan_state(params = {}) ⇒ Types::GetAccountPlanStateResponse
This returns all of the information related to the state of the account plan related to Free Tier.
111 |
# File 'sig/client.rbs', line 111
def get_account_plan_state: (
|
#get_free_tier_usage(params = {}) ⇒ Types::GetFreeTierUsageResponse
Returns a list of all Free Tier usage objects that match your filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
121 |
# File 'sig/client.rbs', line 121
def get_free_tier_usage: (
|
#list_account_activities(params = {}) ⇒ Types::ListAccountActivitiesResponse
Returns a list of activities that are available. This operation supports pagination and filtering by status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
134 |
# File 'sig/client.rbs', line 134
def list_account_activities: (
|
#upgrade_account_plan(params = {}) ⇒ Types::UpgradeAccountPlanResponse
The account plan type for the Amazon Web Services account.
149 |
# File 'sig/client.rbs', line 149
def upgrade_account_plan: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
888 889 890 |
# File 'lib/aws-sdk-freetier/client.rb', line 888 def waiter_names [] end |